collections_extended's documentation
====================================

``collections_extended``, provides
a ``bag`` class, AKA **multiset**,
a ``setlist`` class, which is a **unique list** or **ordered set**,
a ``bijection`` class and ``RangeMap`` which is a mapping from ranges to values.
There are also frozen (hashable) varieties of bags and setlists.

It is `tested against`_ Python 2.6, 2.7, 3.2, 3.3, 3.4 & PyPy.

Contents:

.. toctree::
	:maxdepth: 3

	getting_started
	setlists
	bags
	range_map
	api
	contributing

:Author: Michael Lenzen
:Copyright: 2015 Michael Lenzen
:License: Apache License, Version 2.0
:Documentation: http://collections-extended.lenzm.net/
:GitHub: https://github.com/mlenzen/collections-extended
:PyPI: https://pypi.python.org/pypi/collections-extended


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _`tested against`: https://travis-ci.org/mlenzen/collections-extended
